@@ -1,23 +1,6 @@
-﻿/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:    LZ <zhou.lu@archermind.com>
-*
-* Maintainer:  LZ <zhou.lu@archermind.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "filtercontent.h"
 #include "logcombox.h"
@@ -49,9 +32,11 @@
 
 #define BUTTON_WIDTH_MIN 68
 #define BUTTON_HEIGHT_MIN 36
+#define BUTTON_HEIGHT_MIN_COMPACT 24
 #define BUTTON_EXPORT_WIDTH_MIN 142
 #define FONT_20_MIN_WIDTH 821
 #define FONT_18_MIN_WIDTH 100
+#define LEVEL_COMBO_WIDTH 120
 DWIDGET_USE_NAMESPACE
 
 /**
@@ -110,21 +95,17 @@ void FilterContent::initUI()
     hLayout_period->addWidget(m_lastMonthBtn);
     hLayout_period->addWidget(m_threeMonthBtn);
     hLayout_period->addStretch(1);
-
-    DSuggestButton *cmdLinkBtn = new DSuggestButton(("Reset"), this);
-    cmdLinkBtn->setFlat(true);
-    cmdLinkBtn->hide();
-    m_btnGroup->addButton(cmdLinkBtn, 6);
-    hLayout_period->addWidget(cmdLinkBtn);
     hLayout_period->setSpacing(10);
 
     // set level info
     hLayout_all = new QHBoxLayout;
     QHBoxLayout *hLayout_lvl = new QHBoxLayout;
     lvTxt = new DLabel(DApplication::translate("Label", "Level:  "), this);
+    lvTxt->setAccessibleName(DApplication::translate("Label", "Level:  "));
     lvTxt->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     cbx_lv = new LogCombox(this);
-    cbx_lv->setMinimumSize(QSize(198, BUTTON_HEIGHT_MIN));
+    //cbx_lv->view()->setAccessibleName("combobox_level_view");
+    cbx_lv->setMinimumWidth(LEVEL_COMBO_WIDTH);
     cbx_lv->addItems(QStringList() << DApplication::translate("ComboBox", "All")
                      << DApplication::translate("ComboBox", "Emergency")
                      << DApplication::translate("ComboBox", "Alert")
@@ -141,9 +122,11 @@ void FilterContent::initUI()
     hLayout_all->addLayout(hLayout_lvl);
     QHBoxLayout *hLayout_dnf_lvl = new QHBoxLayout;
     dnflvTxt = new DLabel(DApplication::translate("Label", "Level:  "), this);
+    dnflvTxt->setAccessibleName("dnf" + DApplication::translate("Label", "Level:  "));
     dnflvTxt->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     cbx_dnf_lv = new LogCombox(this);
-    cbx_dnf_lv->setMinimumSize(QSize(198, BUTTON_HEIGHT_MIN));
+    //cbx_dnf_lv->view()->setAccessibleName("combobox_dnflevel_view");
+    cbx_dnf_lv->setMinimumWidth(198);
     cbx_dnf_lv->addItem(DApplication::translate("ComboBox", "All"), DNFLVALL);
     cbx_dnf_lv->addItem(DApplication::translate("ComboBox", "Super critical"), SUPERCRITICAL);
     cbx_dnf_lv->addItem(DApplication::translate("ComboBox", "Critical"), CRITICAL);
@@ -158,21 +141,35 @@ void FilterContent::initUI()
     hLayout_all->addLayout(hLayout_dnf_lvl);
     // set all files under ~/.cache/deepin
     QHBoxLayout *hLayout_app = new QHBoxLayout;
-    appTxt = new DLabel(DApplication::translate("Label", "Application list:"), this);
+    appTxt = new DLabel(DApplication::translate("Label", "Application:"), this);
     cbx_app = new LogCombox(this);
+    //cbx_app->view()->setAccessibleName("combobox_app_view");
 
-    cbx_app->setMinimumSize(QSize(180, BUTTON_HEIGHT_MIN));
+    cbx_app->setMinimumWidth(160);
     hLayout_app->addWidget(appTxt);
     hLayout_app->addWidget(cbx_app, 1);
     hLayout_app->setSpacing(6);
     hLayout_all->addLayout(hLayout_app);
 
+    // app submodules
+    QHBoxLayout *hLayout_submodule = new QHBoxLayout;
+    submoduleTxt = new DLabel(DApplication::translate("Label", "Submodule:"), this);
+    cbx_submodule = new LogCombox(this);
+    //cbx_submodule->view()->setAccessibleName("combobox_submodule_view");
+
+    cbx_submodule->setMinimumWidth(143);
+    hLayout_submodule->addWidget(submoduleTxt);
+    hLayout_submodule->addWidget(cbx_submodule, 1);
+    hLayout_submodule->setSpacing(6);
+    hLayout_all->addLayout(hLayout_submodule);
+
+
     // add status item
     QHBoxLayout *hLayout_status = new QHBoxLayout;
     statusTxt = new DLabel(DApplication::translate("Label", "Status:"), this);
     cbx_status = new LogCombox(this);
+    //cbx_status->view()->setAccessibleName("combobox_status_view");
     cbx_status->setMinimumWidth(120);
-    cbx_status->setMinimumSize(QSize(120, BUTTON_HEIGHT_MIN));
     cbx_status->addItems(QStringList() << DApplication::translate("ComboBox", "All") << "OK"
                          << "Failed");
     hLayout_status->addWidget(statusTxt);
@@ -184,8 +181,8 @@ void FilterContent::initUI()
     QHBoxLayout *hLayout_type = new QHBoxLayout;
     typeTxt = new DLabel(DApplication::translate("Label", "Event Type:"), this);
     typeCbx = new LogCombox(this);
+    //typeCbx->view()->setAccessibleName("combobox_eventtype_view");
     typeCbx->setMinimumWidth(120);
-    typeCbx->setMinimumSize(QSize(120, BUTTON_HEIGHT_MIN));
     typeCbx->addItems(QStringList() << DApplication::translate("ComboBox", "All")
                       << DApplication::translate("ComboBox", "Login")
                       << DApplication::translate("ComboBox", "Boot")
@@ -194,6 +191,24 @@ void FilterContent::initUI()
     hLayout_status->addWidget(typeCbx, 1);
     hLayout_status->setSpacing(6);
     hLayout_all->addLayout(hLayout_type);  // end add
+
+    // 审计日志审计类型筛选下拉框
+    QHBoxLayout *hLayout_auditType = new QHBoxLayout;
+    auditTypeTxt = new DLabel(DApplication::translate("Label", "Audit Type:"), this);
+    auditTypeCbx = new LogCombox(this);
+    auditTypeCbx->setMinimumWidth(120);
+    auditTypeCbx->addItems(QStringList() << DApplication::translate("ComboBox", "All")
+                      << DApplication::translate("ComboBox", "Identity authentication")
+                      << DApplication::translate("ComboBox", "Discretionary Access Control")
+                      << DApplication::translate("ComboBox", "Mandatory access control")
+                      << DApplication::translate("ComboBox", "Remote")
+                      << DApplication::translate("ComboBox", "Document audit")
+                      << DApplication::translate("ComboBox", "Other"));
+    hLayout_status->addWidget(auditTypeTxt);
+    hLayout_status->addWidget(auditTypeCbx, 1);
+    hLayout_status->setSpacing(6);
+    hLayout_all->addLayout(hLayout_auditType);  // end add
+
     hLayout_all->addStretch(1);
     exportBtn = new LogNormalButton(DApplication::translate("Button", "Export", "button"), this);
     exportBtn->setContentsMargins(0, 0, 18, 18);
@@ -232,6 +247,7 @@ void FilterContent::initConnections()
     connect(cbx_status, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxStatusChanged(int)));
     connect(typeCbx, SIGNAL(currentIndexChanged(int)), this,
             SLOT(slot_cbxLogTypeChanged(int)));  // add by Airy
+    connect(auditTypeCbx, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxAuditTypeChanged(int)));
 }
 
 /**
@@ -259,19 +275,47 @@ void FilterContent::setAppComboBoxItem()
     cbx_app->clear();
     //获取应用列表
     auto *appHelper = LogApplicationHelper::instance();
-    QMap<QString, QString> _map = appHelper->getMap();
-    QMap<QString, QString>::const_iterator iter = _map.constBegin();
+    AppLogConfigList appConfigs =  appHelper->getAppLogConfigs();
     //添加数据进combox
-    while (iter != _map.constEnd()) {
-        cbx_app->addItem(iter.key());
-        //应用日志的路径为Qt::UserRole + 1
-        cbx_app->setItemData(cbx_app->count() - 1, iter.value(), Qt::UserRole + 1);
-        ++iter;
+    for (auto appConfig : appConfigs) {
+        // 没有子模块，不在应用列表显示
+        if (appConfig.subModules.size() == 0 || !appConfig.visible)
+            continue;
+
+        if (!appConfig.transName.isEmpty())
+            cbx_app->addItem(appConfig.transName);
+        else
+            cbx_app->addItem(appConfig.name);
+        // 应用日志的项目名称为Qt::UserRole + 1
+        cbx_app->setItemData(cbx_app->count() - 1, appConfig.name, Qt::UserRole + 1);
     }
+
     connect(cbx_app, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxAppIdxChanged(int)), Qt::UniqueConnection);
 
 }
 
+void FilterContent::setSubmodulesComboBoxItem(const QString &app)
+{
+    AppLogConfig logConfig = LogApplicationHelper::instance()->appLogConfig(app);
+
+    // 子模块只有一个，则不显示子模块下拉框
+    if (logConfig.subModules.size() < 2) {
+        submoduleTxt->setVisible(false);
+        cbx_submodule->setVisible(false);
+    } else {
+        submoduleTxt->setVisible(true);
+        cbx_submodule->setVisible(true);
+        disconnect(cbx_submodule, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxSubmoduleChanged(int)));
+        cbx_submodule->clear();
+        cbx_submodule->addItem(DApplication::translate("ComboBox", "All"));
+        for (auto submodule : logConfig.subModules) {
+            cbx_submodule->addItem(submodule.name);
+        }
+        cbx_submodule->setCurrentText(DApplication::translate("ComboBox", "All"));
+        connect(cbx_submodule, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxSubmoduleChanged(int)));
+    }
+}
+
 /**
  * @brief FilterContent::setSelectorVisible 设置筛选控件显示或不显示以适应各种日志类型的筛选情况
  * @param lvCbx 等级筛选下拉框是否显示
@@ -280,9 +324,10 @@ void FilterContent::setAppComboBoxItem()
  * @param period 时间筛选按钮是否显示
  * @param needMove 如果筛选器只有单排布局,则需要移动导出按钮到上排布局,这个参数表示是否把导出按钮移动到上排的布局
  * @param typecbx 开关机日志日志种类筛选下拉框是否显示
+ * @param auditcbx 审计日志审计类型筛选下拉框是否显示
  */
 void FilterContent::setSelectorVisible(bool lvCbx, bool appListCbx, bool statusCbx, bool period,
-                                       bool needMove, bool typecbx, bool dnfCbx)
+                                       bool needMove, bool typecbx, bool dnfCbx, bool auditCbx)
 {
     //先不立马更新界面,等全部更新好控件状态后再更新界面,否则会导致界面跳动
     setUpdatesEnabled(false);
@@ -293,12 +338,18 @@ void FilterContent::setSelectorVisible(bool lvCbx, bool appListCbx, bool statusC
     appTxt->setVisible(appListCbx);
     cbx_app->setVisible(appListCbx);
 
+    submoduleTxt->setVisible(false);
+    cbx_submodule->setVisible(false);
+
     dnflvTxt->setVisible(dnfCbx);
     cbx_dnf_lv->setVisible(dnfCbx);
 
     typeTxt->setVisible(typecbx);  // add by Airy
     typeCbx->setVisible(typecbx);  // add by Airy
 
+    auditTypeTxt->setVisible(auditCbx);
+    auditTypeCbx->setVisible(auditCbx);
+
     periodLabel->setVisible(period);
     //button的setVisible false会触发taborder到下一个可视控件,比如cbx_status,所以先设置button,再设置cbx_status可防止点击后时间筛选button后再切启动日志导致cbx_status自动进入tabfocus状态,但是这样会引起本窗口焦点重置,所以设置完后需要对loglist setfoucs
     for (int i = 0; i < 6; i++) {
@@ -336,14 +387,14 @@ void FilterContent::setSelection(FILTER_CONFIG iConifg)
     if (cbx_lv->isVisible())
         cbx_lv->setCurrentIndex(iConifg.levelCbx);
     if (cbx_app->isVisible()) {
-        QString path = iConifg.appListCbx;
+        QString app = iConifg.appListCbx;
         int appCount =  cbx_app->count();
         int rsIndex = 0;
 
-        if (!path.isEmpty()) {
+        if (!app.isEmpty()) {
             //找原来选的选项的index,如果这个应用日志没了,就选第一个
             for (int i = 0; i < appCount; ++i) {
-                if (cbx_app->itemData(i, Qt::UserRole + 1).toString() == path) {
+                if (cbx_app->itemData(i, Qt::UserRole + 1).toString() == app) {
                     rsIndex = i;
                     break;
                 }
@@ -355,12 +406,27 @@ void FilterContent::setSelection(FILTER_CONFIG iConifg)
         } else {
             cbx_app->setCurrentIndex(rsIndex);
         }
+
+        if (cbx_submodule->isVisible()) {
+
+            int nSubIndex = 0;
+            //找原来选的选项的index,如果这个子模块没了,就选择所有
+            for (int i = 0; i < cbx_submodule->count(); ++i) {
+                if (cbx_submodule->itemText(i) == iConifg.app2Submodule[app]) {
+                    nSubIndex = i;
+                    break;
+                }
+            }
+            cbx_submodule->setCurrentIndex(nSubIndex);
+        }
     }
 
     if (cbx_status->isVisible())
         Q_EMIT cbx_status->currentIndexChanged(iConifg.statusCbx);
     if (typeCbx->isVisible())
         typeCbx->setCurrentIndex(iConifg.typeCbx);
+    if (auditTypeCbx->isVisible())
+        auditTypeCbx->setCurrentIndex(iConifg.auditCbx);
     if (cbx_dnf_lv->isVisible()) {
         cbx_dnf_lv->setCurrentIndex(iConifg.dnfCbx);
     }
@@ -612,6 +678,7 @@ void FilterContent::slot_logCatelogueClicked(const QModelIndex &index)
     setLeftButtonState(true);
     m_curTreeIndex = index;
     //根据日志种类改变布局
+    this->setVisible(true);
     if (itemData.contains(APP_TREE_DATA, Qt::CaseInsensitive)) {
         m_currentType = APP_TREE_DATA;
         this->setAppComboBoxItem();
@@ -630,7 +697,7 @@ void FilterContent::slot_logCatelogueClicked(const QModelIndex &index)
         this->setSelectorVisible(false, false, false, true, true);
     } else if (itemData.contains(XORG_TREE_DATA, Qt::CaseInsensitive)) {
         m_currentType = XORG_TREE_DATA;
-        this->setSelectorVisible(false, false, false, true,
+        this->setSelectorVisible(false, false, false, false,
                                  true);  // modified by Airy for showing  peroid
     } else if (itemData.contains(LAST_TREE_DATA, Qt::CaseInsensitive)) {  // add by Airy
         m_currentType = LAST_TREE_DATA;
@@ -649,6 +716,20 @@ void FilterContent::slot_logCatelogueClicked(const QModelIndex &index)
         m_currentType = DMESG_TREE_DATA;
         this->setSelectorVisible(true, false, false, true,
                                  false);
+    } else if (itemData.contains(OTHER_TREE_DATA)) {
+        m_currentType = OTHER_TREE_DATA;
+        //this->setSelectorVisible(false, false, false, true, false, false, true);
+        this->setVisible(false);
+    } else if (itemData.contains(CUSTOM_TREE_DATA)) {
+        m_currentType = CUSTOM_TREE_DATA;
+        //this->setSelectorVisible(false, false, false, true, false, false, true);
+        this->setVisible(false);
+    } else if (itemData.contains(AUDIT_TREE_DATA)) {
+        m_currentType = AUDIT_TABLE_DATA;
+        this->setSelectorVisible(false, false, false, true, false, false, false, true);
+    } else if (itemData.contains(COREDUMP_TREE_DATA)) {
+        m_currentType = COREDUMP_TREE_DATA;
+        this->setSelectorVisible(false, false, false, true, true, false, false, false);
     }
     updateDataState();
     //必须需要,因为会丢失当前焦点顺序
@@ -766,14 +847,25 @@ void FilterContent::slot_cbxLvIdxChanged(int idx)
 void FilterContent::slot_cbxAppIdxChanged(int idx)
 {
     setChangedcomboxstate(!getLeftButtonState());
-    QString path = cbx_app->itemData(idx, Qt::UserRole + 1).toString();
+    QString app = cbx_app->itemData(idx, Qt::UserRole + 1).toString();
     FILTER_CONFIG curConfig = m_config.value(m_currentType);
-    qDebug() << "apppath" << path;
-    curConfig.appListCbx = path;
+    curConfig.appListCbx = app;
     //变化时改变记录选择选项的数据结构,以便下次还原
     setCurrentConfig(curConfig);
     //发出信号以供数据显示控件刷新数据
-    emit sigCbxAppIdxChanged(curConfig.dateBtn, path);
+    emit sigCbxAppIdxChanged(curConfig.dateBtn, app);
+
+    // 初始化子模块列表
+    setSubmodulesComboBoxItem(app);
+}
+
+void FilterContent::slot_cbxSubmoduleChanged(int idx)
+{
+    setChangedcomboxstate(true);
+    FILTER_CONFIG curConfig = m_config.value(m_currentType);
+    curConfig.app2Submodule[curConfig.appListCbx] = cbx_submodule->currentText();
+    setCurrentConfig(curConfig);
+    emit sigCbxSubModuleChanged(idx);
 }
 
 /**
@@ -807,7 +899,15 @@ void FilterContent::slot_cbxLogTypeChanged(int idx)
     curConfig.typeCbx = idx;
     setCurrentConfig(curConfig);
     emit sigLogtypeChanged(idx);
-    qDebug() << "emit signal " + QString::number(idx);
+}
+
+void FilterContent::slot_cbxAuditTypeChanged(int idx)
+{
+    setChangedcomboxstate(true);
+    FILTER_CONFIG curConfig = m_config.value(m_currentType);
+    curConfig.auditCbx = idx;
+    setCurrentConfig(curConfig);
+    emit sigAuditTypeChanged(idx);
 }
 
 /**
