@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     zyc <zyc@uniontech.com>
-*
-* Maintainer:  zyc <zyc@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logdetailinfowidget.h"
 
@@ -86,6 +69,8 @@ void logDetailInfoWidget::cleanText()
     m_nameLabel->hide();
     m_event->hide();
     m_eventLabel->hide();
+
+    m_errorLabel->hide();
 }
 
 /**
@@ -111,58 +96,34 @@ void logDetailInfoWidget::initUI()
     DFontSizeManager::instance()->bind(m_daemonName, DFontSizeManager::T5);
     m_dateTime = new DLabel(this);
     DFontSizeManager::instance()->bind(m_dateTime, DFontSizeManager::T8);
-    DPalette pa = DApplicationHelper::instance()->palette(m_dateTime);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_dateTime, pa);
 
     m_userName = new DLabel(this);
     DFontSizeManager::instance()->bind(m_userName, DFontSizeManager::T8);
     m_userName->setMinimumWidth(LABEL_MIN_WIDTH);
-    pa = DApplicationHelper::instance()->palette(m_userName);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_userName, pa);
 
     m_pid = new DLabel(this);
     DFontSizeManager::instance()->bind(m_pid, DFontSizeManager::T8);
     m_pid->setMinimumWidth(LABEL_MIN_WIDTH);
-    pa = DApplicationHelper::instance()->palette(m_pid);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_pid, pa);
 
     m_action = new DLabel(this);
     DFontSizeManager::instance()->bind(m_action, DFontSizeManager::T8);
     m_action->setMinimumWidth(LABEL_MIN_WIDTH);
-    pa = DApplicationHelper::instance()->palette(m_action);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_action, pa);
 
     m_status = new DLabel(this);
     DFontSizeManager::instance()->bind(m_status, DFontSizeManager::T8);
     m_status->setMinimumWidth(LABEL_MIN_WIDTH);
-    pa = DApplicationHelper::instance()->palette(m_status);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_status, pa);
 
     m_level = new LogIconButton(this);
     DFontSizeManager::instance()->bind(m_level, DFontSizeManager::T8);
-    pa = DApplicationHelper::instance()->palette(m_level);
-    pa.setBrush(DPalette::ButtonText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_level, pa);
 
     // add by Airy
     m_event = new DLabel(this);
     DFontSizeManager::instance()->bind(m_event, DFontSizeManager::T8);
     m_event->setMinimumWidth(LABEL_MIN_WIDTH);
-    pa = DApplicationHelper::instance()->palette(m_event);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_event, pa);
 
     m_name = new DLabel(this);
     DFontSizeManager::instance()->bind(m_name, DFontSizeManager::T8);
     m_name->setMinimumWidth(LABEL_MIN_WIDTH);
-    pa = DApplicationHelper::instance()->palette(m_name);
-    pa.setBrush(DPalette::WindowText, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_name, pa);  // end
 
     m_userLabel = new DLabel(DApplication::translate("Label", "User:"), this);
     DFontSizeManager::instance()->bind(m_userLabel, DFontSizeManager::T7);
@@ -178,53 +139,54 @@ void logDetailInfoWidget::initUI()
     m_nameLabel = new DLabel(DApplication::translate("Label", "Username:"), this);  // add by Airy
     DFontSizeManager::instance()->bind(m_nameLabel, DFontSizeManager::T7);
 
+    m_errorLabel = new DLabel("", this);
+    m_errorLabel->setMinimumWidth(70);
+    m_errorLabel->setMinimumHeight(20);
+    DFontSizeManager::instance()->bind(m_userLabel, DFontSizeManager::T7);
 
     m_hline = new DHorizontalLine;
 
     //不设置nofocus焦点会上到这上面来,可是我们不需要它可以有焦点
     m_textBrowser->setFocusPolicy(Qt::NoFocus);
     DFontSizeManager::instance()->bind(m_textBrowser, DFontSizeManager::T8);
-    pa = DApplicationHelper::instance()->palette(m_textBrowser);
-    pa.setBrush(DPalette::Text, pa.color(DPalette::TextTips));
-    DApplicationHelper::instance()->setPalette(m_textBrowser, pa);
     m_textBrowser->setFrameShape(QFrame::NoFrame);
     m_textBrowser->viewport()->setAutoFillBackground(false);
 
     cleanText();
 
-    QVBoxLayout *v = new QVBoxLayout(this);
+    m_bottomLayer = new QVBoxLayout(this);
 
-    QHBoxLayout *h1 = new QHBoxLayout(this);
+    QHBoxLayout *h1 = new QHBoxLayout();
     h1->addWidget(m_daemonName);
     h1->addStretch(1);
     h1->addWidget(m_dateTime);
 
-    QHBoxLayout *h2 = new QHBoxLayout(this);
+    QHBoxLayout *h2 = new QHBoxLayout();
 
-    QHBoxLayout *h21 = new QHBoxLayout(this);
+    QHBoxLayout *h21 = new QHBoxLayout();
     h21->addWidget(m_userLabel);
     h21->addWidget(m_userName, 1);
     h21->setSpacing(0);
-    QHBoxLayout *h22 = new QHBoxLayout(this);
+    QHBoxLayout *h22 = new QHBoxLayout();
     h22->addWidget(m_pidLabel);
     h22->addWidget(m_pid, 1);
     h22->setSpacing(0);
-    QHBoxLayout *h23 = new QHBoxLayout(this);
+    QHBoxLayout *h23 = new QHBoxLayout();
     h23->addWidget(m_statusLabel);
     h23->addWidget(m_status, 1);
     h23->setSpacing(0);
-    QHBoxLayout *h24 = new QHBoxLayout(this);
+    QHBoxLayout *h24 = new QHBoxLayout();
     h24->addWidget(m_actionLabel);
     h24->addWidget(m_action, 1);
     h24->setSpacing(0);
 
     // add by Airy
-    QHBoxLayout *h25 = new QHBoxLayout(this);
+    QHBoxLayout *h25 = new QHBoxLayout();
     h25->addWidget(m_eventLabel);
     h25->addWidget(m_event, 1);
     h25->setSpacing(8);
 
-    QHBoxLayout *h26 = new QHBoxLayout(this);
+    QHBoxLayout *h26 = new QHBoxLayout();
     h26->addWidget(m_nameLabel);
     h26->addWidget(m_name, 1);
     h26->setSpacing(8);
@@ -241,15 +203,16 @@ void logDetailInfoWidget::initUI()
     h2->addWidget(m_level);
     h2->setSpacing(20);
 
-    v->addLayout(h1);
-    v->addLayout(h2);
-    v->addWidget(m_hline);
-    v->addWidget(m_textBrowser, 3);
+    m_bottomLayer->addLayout(h1);
+    m_bottomLayer->addLayout(h2);
+    m_bottomLayer->addWidget(m_hline);
+    m_bottomLayer->addWidget(m_textBrowser, 3);
+    m_bottomLayer->addWidget(m_errorLabel, 0, Qt::AlignCenter);
 
-    v->setContentsMargins(20, 10, 20, 0);
-    v->setSpacing(4);
+    m_bottomLayer->setContentsMargins(20, 10, 20, 0);
+    m_bottomLayer->setSpacing(4);
 
-    this->setLayout(v);
+    this->setLayout(m_bottomLayer);
 }
 
 void logDetailInfoWidget::setTextCustomSize(QWidget *w)
@@ -313,6 +276,8 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
                                          QString status, QString action, QString uname,
                                          QString event)
 {
+    m_hline->show();
+    m_errorLabel->hide();
     if (deamonName.isEmpty()) {
         m_daemonName->hide();
     } else {
@@ -334,7 +299,7 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
     } else {
         m_dateTime->show();
         QStringList dtlist = dateTime.split(".");
-        if (dtlist.count() == 2)
+        if (dtlist.count() == 2 && deamonName != "Xorg")
             m_dateTime->setText(dtlist[0]);
         else
             m_dateTime->setText(dateTime);
@@ -395,7 +360,41 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
     }
     // end
 
+    m_bottomLayer->setContentsMargins(20, 10, 20, 0);
     m_textBrowser->setText(msg);
+    m_textBrowser->show();
+}
+
+void logDetailInfoWidget::fillOOCDetailInfo(const QString &data, const int error)
+{
+    m_daemonName->hide();
+    m_dateTime->hide();
+    m_userName->hide();
+    m_pid->hide();
+    m_action->hide();
+    m_status->hide();
+    m_name->hide();
+    m_event->hide();
+
+    m_hline->hide();
+
+    m_userLabel->hide();
+    m_pidLabel->hide();
+    m_statusLabel->hide();
+    m_actionLabel->hide();
+    m_nameLabel->hide();
+    m_eventLabel->hide();
+
+    m_bottomLayer->setContentsMargins(20, 10, 0, 0);
+    if (error == 0) {
+        m_textBrowser->setText(data);
+        m_textBrowser->show();
+        m_errorLabel->hide();
+    } else {
+        m_textBrowser->hide();
+        m_errorLabel->show();
+        m_errorLabel->setText(data);
+    }
 }
 
 /**
@@ -405,7 +404,7 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
  * @param name 应用日志的应用名称
  */
 void logDetailInfoWidget::slot_DetailInfo(const QModelIndex &index, QStandardItemModel *pModel,
-                                          QString name)
+                                          const QString &data, const int error)
 {
     cleanText();
 
@@ -449,7 +448,7 @@ void logDetailInfoWidget::slot_DetailInfo(const QModelIndex &index, QStandardIte
                        index.siblingAtColumn(2).data().toString(), index,
                        index.siblingAtColumn(3).data().toString());
     } else if (dataStr.contains(APP_TABLE_DATA)) {
-        fillDetailInfo(name, hostname, "", index.siblingAtColumn(1).data().toString(), index,
+        fillDetailInfo(data, hostname, "", index.siblingAtColumn(1).data().toString(), index,
                        index.siblingAtColumn(3).data(Qt::UserRole + 99).toString());
     } else if (dataStr.contains(LAST_TABLE_DATA)) {
         //        fillDetailInfo("Event", m_pModel->item(index.row(), 0)->text(), "",
@@ -486,5 +485,21 @@ void logDetailInfoWidget::slot_DetailInfo(const QModelIndex &index, QStandardIte
     } else if (dataStr.contains(DMESG_TABLE_DATA)) {
         fillDetailInfo("kernel", hostname, "", index.siblingAtColumn(1).data().toString(), index,
                        index.siblingAtColumn(2).data().toString());
+    } else if (dataStr.contains(OOC_TABLE_DATA)) {
+        fillOOCDetailInfo(data, error);
+    } else if (dataStr.contains(AUDIT_TABLE_DATA)) {
+        fillDetailInfo("audit", hostname, "", index.siblingAtColumn(1).data().toString(), QModelIndex(),
+                       index.siblingAtColumn(4).data().toString(),
+                       index.siblingAtColumn(3).data().toString(),
+                       "",
+                       "",
+                       index.siblingAtColumn(0).data().toString());
+    } else if (dataStr.contains(COREDUMP_TABLE_DATA)) {
+        fillDetailInfo(index.siblingAtColumn(3).data().toString(), hostname, "", index.siblingAtColumn(1).data().toString(), QModelIndex(),
+                       index.siblingAtColumn(4).data(Qt::UserRole + 2).toString(),
+                       index.siblingAtColumn(2).data().toString(),
+                       "",
+                       "",
+                       "");
     }
 }
