@@ -1,28 +1,14 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:    LZ <zhou.lu@archermind.com>
-*
-* Maintainer:  LZ <zhou.lu@archermind.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "loglistview.h"
 #include "logapplicationhelper.h"
 #include "dbusmanager.h"
 #include "DebugTimeManager.h"
+#include "logapplicationhelper.h"
+#include "dbusproxy/dldbushandler.h"
+#include "utils.h"
 
 #include <DDesktopServices>
 #include <DDialog>
@@ -36,7 +22,6 @@
 #include <QItemSelectionModel>
 #include <QMargins>
 #include <QPaintEvent>
-#include <QStandardItemModel>
 #include <QPainter>
 #include <QProcess> //add by Airy
 #include <QDebug>
@@ -48,6 +33,7 @@
 #include <QShortcut>
 #include <QAbstractButton>
 #define ITEM_HEIGHT 40
+#define ITEM_HEIGHT_COMPACT 24
 #define ITEM_WIDTH 108
 #define ICON_SIZE 16
 
@@ -57,6 +43,8 @@ Q_DECLARE_METATYPE(QMargins)
 
 DWIDGET_USE_NAMESPACE
 
+const QVariant VListViewItemMargin = QVariant::fromValue(QMargins(15, 0, 5, 0));
+
 LogListDelegate::LogListDelegate(LogListView *parent)
     : DStyledItemDelegate(parent)
 {
@@ -137,7 +125,7 @@ LogListView::LogListView(QWidget *parent)
     initUI();
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, &LogListView::customContextMenuRequested, this, &LogListView::requestshowRightMenu);
-    DGuiApplicationHelper::ColorType ct = DApplicationHelper::instance()->themeType();
+    //DGuiApplicationHelper::ColorType ct = DApplicationHelper::instance()->themeType();
 
     m_rightClickTriggerShortCut = new QShortcut(this);
     m_rightClickTriggerShortCut->setKey(Qt::ALT + Qt::Key_M);
@@ -147,6 +135,14 @@ LogListView::LogListView(QWidget *parent)
         QRect r = rectForIndex(this->currentIndex());
         showRightMenu(QPoint(r.x() + r.width() / 2, r.y() + r.height() / 2), true);
     });
+
+    connect(LogApplicationHelper::instance(), &LogApplicationHelper::sigValueChanged, this, &LogListView::slot_valueChanged_dConfig_or_gSetting);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    // 紧凑模式信号处理
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, &LogListView::updateSizeMode);
+    updateSizeMode();
+#endif
 }
 
 /**
@@ -159,15 +155,11 @@ void LogListView::initUI()
     this->setItemDelegate(new LogListDelegate(this));
     this->setItemSpacing(0);
     this->setViewportMargins(10, 10, 10, 0);
-    const QMargins ListViweItemMargin(15, 0, 5, 0);
-    const QVariant VListViewItemMargin = QVariant::fromValue(ListViweItemMargin);
     Dtk::Core::DSysInfo::UosEdition edition = Dtk::Core::DSysInfo::uosEditionType();
     //等于服务器行业版或欧拉版(centos)
-    bool isCentos = Dtk::Core::DSysInfo::UosEuler == edition || Dtk::Core::DSysInfo::UosEnterpriseC == edition;
+    bool isCentos = Dtk::Core::DSysInfo::UosEuler == edition || Dtk::Core::DSysInfo::UosEnterpriseC == edition || Dtk::Core::DSysInfo::UosMilitaryS == edition;
     m_pModel = new QStandardItemModel(this);
     QStandardItem *item = nullptr;
-    QString systemName = DBusManager::getSystemInfo();
-    qDebug() << "systemName" << systemName;
     if (isFileExist("/var/log/journal") || isCentos) {
         item = new QStandardItem(QIcon::fromTheme("dp_system"), DApplication::translate("Tree", "System Log"));
         setIconSize(QSize(ICON_SIZE, ICON_SIZE));
@@ -175,7 +167,6 @@ void LogListView::initUI()
         item->setData(JOUR_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("System Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(JOUR_TREE_DATA);
     }
@@ -187,7 +178,6 @@ void LogListView::initUI()
         item->setData(DMESG_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("dmesg Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(DMESG_TREE_DATA);
     } else {
@@ -198,19 +188,17 @@ void LogListView::initUI()
             item->setData(KERN_TREE_DATA, ITEM_DATE_ROLE);
             item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
             item->setData(VListViewItemMargin, Dtk::MarginsRole);
-            item->setAccessibleText("Kernel Log");
             m_pModel->appendRow(item);
             m_logTypes.push_back(KERN_TREE_DATA);
         }
     }
-    if (systemName == "klu" || systemName == "panguV" || systemName == "W515 PGUV-WBY0" || systemName.toUpper().contains("PGUV") || systemName.toUpper().contains("PANGUV") || systemName.toUpper().contains("KLU")) {
+    if (Utils::isWayland()) {
         item = new QStandardItem(QIcon::fromTheme("dp_start"), DApplication::translate("Tree", "Boot Log"));
         setIconSize(QSize(ICON_SIZE, ICON_SIZE));
         item->setToolTip(DApplication::translate("Tree", "Boot Log")); // add by Airy for bug 16245
         item->setData(BOOT_KLU_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("Boot Klu Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(BOOT_KLU_TREE_DATA);
     } else {
@@ -220,7 +208,6 @@ void LogListView::initUI()
         item->setData(BOOT_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("Boot Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(BOOT_TREE_DATA);
     }
@@ -231,7 +218,6 @@ void LogListView::initUI()
         item->setData(DNF_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("dnf Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(DNF_TREE_DATA);
     } else {
@@ -242,20 +228,18 @@ void LogListView::initUI()
             item->setData(DPKG_TREE_DATA, ITEM_DATE_ROLE);
             item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
             item->setData(VListViewItemMargin, Dtk::MarginsRole);
-            item->setAccessibleText("dpkg Log");
             m_pModel->appendRow(item);
             m_logTypes.push_back(DPKG_TREE_DATA);
         }
     }
-    //w515是新版本内核的panguv返回值  panguV是老版本
-    if (systemName == "klu" || systemName == "panguV" || systemName == "W515 PGUV-WBY0" || systemName == "pangu" || systemName.toUpper().contains("PGUV") || systemName.toUpper().contains("PANGUV") || systemName.toUpper().contains("KLU") || systemName.toUpper().contains("PANGU")) {
+    //wayland环境才有kwin日志
+    if (Utils::isWayland()) {
         item = new QStandardItem(QIcon::fromTheme("dp_kwin"), DApplication::translate("Tree", "Kwin Log"));
         setIconSize(QSize(ICON_SIZE, ICON_SIZE));
         item->setToolTip(DApplication::translate("Tree", "Kwin Log"));
         item->setData(KWIN_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("dpkg Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(KWIN_TREE_DATA);
     } else {
@@ -265,7 +249,6 @@ void LogListView::initUI()
         item->setData(XORG_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("Xorg Log");
         m_pModel->appendRow(item);
         m_logTypes.push_back(XORG_TREE_DATA);
     }
@@ -279,11 +262,22 @@ void LogListView::initUI()
         item->setData(APP_TREE_DATA, ITEM_DATE_ROLE);
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("Application Log");
         m_pModel->appendRow(item);
         this->setModel(m_pModel);
-        m_logTypes.push_back(APP_TREE_DATA);
+        m_logTypes.push_back(APP_TREE_DATA);  
     }
+
+    // coredump log
+    item = new QStandardItem(QIcon::fromTheme("dp_customlog"), DApplication::translate("Tree", "Coredump Log"));
+    setIconSize(QSize(ICON_SIZE, ICON_SIZE));
+    item->setToolTip(DApplication::translate("Tree", "Coredump Log"));
+    item->setData(COREDUMP_TREE_DATA, ITEM_DATE_ROLE);
+    item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
+    item->setData(VListViewItemMargin, Dtk::MarginsRole);
+    m_pModel->appendRow(item);
+    m_logTypes.push_back(COREDUMP_TREE_DATA);
+
+
     // add by Airy
     if (isFileExist("/var/log/wtmp")) {
         item = new QStandardItem(QIcon::fromTheme("dp_onoff"), DApplication::translate("Tree", "Boot-Shutdown Event"));
@@ -293,15 +287,76 @@ void LogListView::initUI()
             DApplication::translate("Tree", "Boot-Shutdown Event")); // add by Airy for bug 16245
         item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
         item->setData(VListViewItemMargin, Dtk::MarginsRole);
-        item->setAccessibleText("Boot-Shutdown Event");
         m_pModel->appendRow(item);
         this->setModel(m_pModel);
         m_logTypes.push_back(LAST_TREE_DATA);
     }
+
+    //other
+    item = new QStandardItem(QIcon::fromTheme("dp_customlog", QIcon(":/customlog.svg")), DApplication::translate("Tree", "Other Log"));
+    setIconSize(QSize(ICON_SIZE, ICON_SIZE));
+    item->setToolTip(DApplication::translate("Tree", "Other Log"));
+    item->setData(OTHER_TREE_DATA, ITEM_DATE_ROLE);
+    item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
+    item->setData(VListViewItemMargin, Dtk::MarginsRole);
+    m_pModel->appendRow(item);
+    m_logTypes.push_back(OTHER_TREE_DATA);
+
+    //custom
+    if (LogApplicationHelper::instance()->getCustomLogList().size()) {
+        m_logTypes.push_back(CUSTOM_TREE_DATA);
+        initCustomLogItem();
+    }
+
+    // 审计日志 （因dbus安全整改要求，isFileExist接口需要进行polkit鉴权，因此调整为程序启动时默认显示审计日志）
+    item = new QStandardItem(QIcon::fromTheme("dp_customlog"), DApplication::translate("Tree", "Audit Log"));
+    setIconSize(QSize(ICON_SIZE, ICON_SIZE));
+    item->setToolTip(DApplication::translate("Tree", "Audit Log"));
+    item->setData(AUDIT_TREE_DATA, ITEM_DATE_ROLE);
+    item->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
+    item->setData(VListViewItemMargin, Dtk::MarginsRole);
+    m_pModel->appendRow(item);
+    m_logTypes.push_back(AUDIT_TREE_DATA);
+
+    DLDBusHandler::instance(this)->whiteListOutPaths();
+
     // set first item is select when app start
     if (m_pModel->rowCount() > 0) {
         this->setCurrentIndex(m_pModel->index(0, 0));
+    }  
+}
+
+void LogListView::initCustomLogItem()
+{
+    if (!m_customLogItem) {
+        m_customLogItem = new QStandardItem(QIcon::fromTheme("dp_customlog", QIcon(":/customlog.svg")), DApplication::translate("Tree", "Custom Log"));
     }
+
+    setIconSize(QSize(ICON_SIZE, ICON_SIZE));
+    m_customLogItem->setToolTip(DApplication::translate("Tree", "Custom Log"));
+    m_customLogItem->setData(CUSTOM_TREE_DATA, ITEM_DATE_ROLE);
+    m_customLogItem->setSizeHint(QSize(ITEM_WIDTH, ITEM_HEIGHT));
+    m_customLogItem->setData(VListViewItemMargin, Dtk::MarginsRole);
+    m_pModel->appendRow(m_customLogItem);
+}
+
+QStringList LogListView::getAllFiles(const QString &file)
+{
+    QStringList files;
+    if (file.contains("*")) {
+        QString path = file.left(file.lastIndexOf('/'));
+        QDir dir(path);
+        QStringList filters;
+        filters << file.split('/').last();
+        files = dir.entryList(filters, QDir::Files);
+
+        for (auto &file : files) {
+            file = path + "/" + file;
+        }
+    } else {
+        files << file;
+    }
+    return files;
 }
 
 void LogListView::setDefaultSelect()
@@ -363,17 +418,19 @@ void LogListView::truncateFile(QString path_)
 {
     QProcess prc;
     if (path_ == KERN_TREE_DATA || path_ == BOOT_TREE_DATA || path_ == DPKG_TREE_DATA || path_ == KWIN_TREE_DATA) {
-        prc.start("pkexec", QStringList() << "logViewerTruncate" << path_.append("*"));
+        QStringList files = getAllFiles(path_.append("*"));
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     } else if (path_ == XORG_TREE_DATA) {
         path_ = "/var/log/Xorg*.log*";
-        prc.start("pkexec", QStringList() << "logViewerTruncate" << path_);
+        QStringList files = getAllFiles(path_);
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     } else if (path_ == DNF_TREE_DATA) {
         path_ = "/var/log/dnf*.log*";
-        prc.start("pkexec", QStringList() << "logViewerTruncate" << path_);
+        QStringList files = getAllFiles(path_);
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     } else {
-        QStringList arg;
-        arg << "-c" << QString("truncate -s 0 %1").arg(path_.append("*"));
-        prc.start("/bin/bash", arg);
+        QStringList files = getAllFiles(path_.append("*"));
+        prc.start("pkexec", QStringList() << "logViewerTruncate" << files.join(' '));
     }
 
     prc.waitForFinished();
@@ -382,12 +439,28 @@ void LogListView::truncateFile(QString path_)
 /**
  * @author Airy
  * @brief LogListView::slot_getAppPath  清空应用日志时，当前显示应用日志的目录由外部提供并赋予成员变量
- * @param path 要设置的当前应用路径
+ * @param app 要设置的当前应用项目名称
  */
-void LogListView::slot_getAppPath(int id, QString path)
+void LogListView::slot_getAppPath(int id, const QString &app)
 {
     Q_UNUSED(id);
-    g_path = path;
+
+    AppLogConfig appConfig = LogApplicationHelper::instance()->appLogConfig(app);
+    if (!appConfig.isValid())
+        g_path = "";
+    else {
+        std::vector<SubModuleConfig> vSubmodules = appConfig.subModules.toVector().toStdVector();
+        auto it = std::find_if(vSubmodules.begin(), vSubmodules.end(), [=](SubModuleConfig submodule) {
+            return submodule.logType == "file" && submodule.name == appConfig.name;
+        });
+
+        if (it != vSubmodules.end()) {
+            g_path = it->logPath;
+            return;
+        }
+
+        g_path = "";
+    }
 }
 
 Qt::FocusReason LogListView::focusReson()
@@ -397,7 +470,6 @@ Qt::FocusReason LogListView::focusReson()
 
 void LogListView::showRightMenu(const QPoint &pos, bool isUsePoint)
 {
-    qDebug() << __FUNCTION__;
     QModelIndex idx = this->currentIndex();
     QString pathData = idx.data(ITEM_DATE_ROLE).toString();
     if (!this->selectionModel()->selectedIndexes().empty()) {
@@ -410,7 +482,9 @@ void LogListView::showRightMenu(const QPoint &pos, bool isUsePoint)
         g_context->addAction(g_clear);
         g_context->addAction(g_refresh);
 
-        if (pathData == JOUR_TREE_DATA || pathData == LAST_TREE_DATA || pathData == BOOT_KLU_TREE_DATA) {
+        if (pathData == JOUR_TREE_DATA || pathData == LAST_TREE_DATA || pathData == BOOT_KLU_TREE_DATA
+                || pathData == OTHER_TREE_DATA || pathData == CUSTOM_TREE_DATA || pathData == AUDIT_TREE_DATA
+                || pathData == COREDUMP_TREE_DATA) {
             g_clear->setEnabled(false);
             g_openForder->setEnabled(false);
         }
@@ -418,7 +492,8 @@ void LogListView::showRightMenu(const QPoint &pos, bool isUsePoint)
             g_clear->setEnabled(false);
             g_openForder->setEnabled(false);
         }
-        QString dirPath = QDir::homePath();
+
+        QString dirPath = Utils::homePath;
         QString _path_ = g_path; //get app path
         QString path = "";
 
@@ -426,10 +501,17 @@ void LogListView::showRightMenu(const QPoint &pos, bool isUsePoint)
             path = pathData;
         } else if (pathData == APP_TREE_DATA) {
             path = _path_;
+            g_clear->setEnabled(!path.isEmpty());
+            g_openForder->setEnabled(!path.isEmpty());
         }
+
         //显示当前日志目录
         connect(g_openForder, &QAction::triggered, this, [=] {
-            DDesktopServices::showFileItem(path);
+            if (pathData != COREDUMP_TREE_DATA) {
+                DDesktopServices::showFileItem(path);
+            } else {
+                DDesktopServices::showFolder(path);
+            }
         });
 
         QModelIndex index = idx;
@@ -521,3 +603,41 @@ void LogListView::focusOutEvent(QFocusEvent *event)
 {
     DListView::focusOutEvent(event);
 }
+
+void LogListView::slot_valueChanged_dConfig_or_gSetting(const QString &key)
+{
+    if (key == "customLogFiles" || key == "customlogfiles") {
+        int size = LogApplicationHelper::instance()->getCustomLogList().size();
+        if (size > 0 && (!m_customLogItem || !m_pModel->indexFromItem(m_customLogItem).isValid())) {
+            initCustomLogItem();
+        } else if(size <= 0 && m_customLogItem && m_pModel->indexFromItem(m_customLogItem).isValid()) {
+            // set first item is select
+            if (currentIndex() == m_customLogItem->index()) {
+               this->setCurrentIndex(m_pModel->index(0, 0));
+            }
+            m_pModel->removeRow(m_customLogItem->row());
+            m_customLogItem = nullptr;
+        }
+    }
+}
+
+void LogListView::updateSizeMode()
+{
+    int nItemHeight = ITEM_HEIGHT;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::isCompactMode())
+        nItemHeight = ITEM_HEIGHT_COMPACT;
+    else
+        nItemHeight = ITEM_HEIGHT;
+#else
+    nItemHeight = ITEM_HEIGHT;
+#endif
+
+    if (m_pModel) {
+        int nCount = m_pModel->rowCount();
+        for (int i = 0; i < nCount; i++) {
+            QStandardItem* item = m_pModel->item(i);
+            item->setSizeHint(QSize(ITEM_WIDTH, nItemHeight));
+        }
+    }
+}
